==> haskell-postgresql-binary-0.12.5-155-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-postgresql-binary.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 postgresql-binary
version:              0.12.5
visibility:           public
id:                   postgresql-binary-0.12.5-3bBjFQUqxQ1BsZHVHZckVw
key:                  postgresql-binary-0.12.5-3bBjFQUqxQ1BsZHVHZckVw
license:              MIT
copyright:            (c) 2014, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/postgresql-binary 
synopsis:             Encoders and decoders for the PostgreSQL'\''s binary format
description:
    An API for dealing with PostgreSQL'\''s binary data format.

    It can be used to implement performant bindings to Postgres.
    E.g., <http://hackage.haskell.org/package/hasql hasql>
    is based on this library.

    It supports all Postgres versions starting from 8.3
    and is tested against 8.3, 9.3 and 9.5
    with the @integer_datetimes@ setting off and on.

category:             PostgreSQL, Database, Codecs, Parsing
abi:                  cb4afadb3b77c6f30f35434c9e8402c9
exposed:              True
exposed-modules:
    PostgreSQL.Binary.Data PostgreSQL.Binary.Decoding
    PostgreSQL.Binary.Encoding

hidden-modules:
    PostgreSQL.Binary.Encoding.Builders PostgreSQL.Binary.Prelude
    PostgreSQL.Binary.Integral PostgreSQL.Binary.Interval
    PostgreSQL.Binary.Numeric PostgreSQL.Binary.Time
    PostgreSQL.Binary.Inet PostgreSQL.Binary.BuilderPrim

import-dirs:          /usr/lib/ghc-9.4.8/site-local/postgresql-binary-0.12.5
library-dirs:         /usr/lib/ghc-9.4.8/site-local/postgresql-binary-0.12.5
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/postgresql-binary-0.12.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-postgresql-binary
hs-libraries:         HSpostgresql-binary-0.12.5-3bBjFQUqxQ1BsZHVHZckVw
depends:
    aeson-2.1.2.1-KaceSWeAWkBK9urIr7RMHq base-4.17.2.1
    binary-parser-0.5.7.6-HKRlHTHpFJ6Enxwglazko6 bytestring-0.11.5.3
    bytestring-strict-builder-0.4.5.7-ItV2qb71fsqAi2BY5ieFyE
    containers-0.6.7 network-ip-0.3.0.3-1txXuegsWP1BLL4fXoXced
    scientific-0.3.7.0-9lDvYfmnlPP71p7oN4wX8g text-2.0.2 time-1.12.2
    transformers-0.5.6.2
    unordered-containers-0.2.20-LkuwqgGHy2J6l9MBSYA9kS
    uuid-1.3.16-An2m5s9X7Fb7K8jTGqtNlw
    vector-0.13.1.0-GCmMsLcrTyFGJ15LkY6umX

haddock-interfaces:
    /usr/share/doc/haskell-postgresql-binary/html/postgresql-binary.haddock

haddock-html:         /usr/share/doc/haskell-postgresql-binary/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-postgresql-binary-0.12.5-156-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-postgresql-binary.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 postgresql-binary
version:              0.12.5
visibility:           public
id:                   postgresql-binary-0.12.5-7kRNusrUWPu92OVjocVTwI
key:                  postgresql-binary-0.12.5-7kRNusrUWPu92OVjocVTwI
license:              MIT
copyright:            (c) 2014, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/postgresql-binary 
synopsis:             Encoders and decoders for the PostgreSQL'\''s binary format
description:
    An API for dealing with PostgreSQL'\''s binary data format.

    It can be used to implement performant bindings to Postgres.
    E.g., <http://hackage.haskell.org/package/hasql hasql>
    is based on this library.

    It supports all Postgres versions starting from 8.3
    and is tested against 8.3, 9.3 and 9.5
    with the @integer_datetimes@ setting off and on.

category:             PostgreSQL, Database, Codecs, Parsing
abi:                  114e0be57868ba57eaf5462df255f3a2
exposed:              True
exposed-modules:
    PostgreSQL.Binary.Data PostgreSQL.Binary.Decoding
    PostgreSQL.Binary.Encoding

hidden-modules:
    PostgreSQL.Binary.Encoding.Builders PostgreSQL.Binary.Prelude
    PostgreSQL.Binary.Integral PostgreSQL.Binary.Interval
    PostgreSQL.Binary.Numeric PostgreSQL.Binary.Time
    PostgreSQL.Binary.Inet PostgreSQL.Binary.BuilderPrim

import-dirs:          /usr/lib/ghc-9.4.8/site-local/postgresql-binary-0.12.5
library-dirs:         /usr/lib/ghc-9.4.8/site-local/postgresql-binary-0.12.5
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/postgresql-binary-0.12.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-postgresql-binary
hs-libraries:         HSpostgresql-binary-0.12.5-7kRNusrUWPu92OVjocVTwI
depends:
    aeson-2.1.2.1-KaceSWeAWkBK9urIr7RMHq base-4.17.2.1
    binary-parser-0.5.7.6-HKRlHTHpFJ6Enxwglazko6 bytestring-0.11.5.3
    bytestring-strict-builder-0.4.5.7-7mpR9IoUV4hFta4wHUelS6
    containers-0.6.7 network-ip-0.3.0.3-1txXuegsWP1BLL4fXoXced
    scientific-0.3.7.0-9lDvYfmnlPP71p7oN4wX8g text-2.0.2 time-1.12.2
    transformers-0.5.6.2
    unordered-containers-0.2.20-LkuwqgGHy2J6l9MBSYA9kS
    uuid-1.3.16-An2m5s9X7Fb7K8jTGqtNlw
    vector-0.13.1.0-GCmMsLcrTyFGJ15LkY6umX

haddock-interfaces:
    /usr/share/doc/haskell-postgresql-binary/html/postgresql-binary.haddock

haddock-html:         /usr/share/doc/haskell-postgresql-binary/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
